package com.ruoyi.project.ehs.service;

import java.util.List;
import com.ruoyi.project.ehs.domain.THighpresfire;

/**
 * 高压消防炮Service接口
 * 
 * @author ruoyi
 * @date 2020-11-25
 */
public interface ITHighpresfireService 
{
    /**
     * 查询高压消防炮
     * 
     * @param id 高压消防炮ID
     * @return 高压消防炮
     */
    public THighpresfire selectTHighpresfireById(Long id);

    /**
     * 查询高压消防炮列表
     * 
     * @param tHighpresfire 高压消防炮
     * @return 高压消防炮集合
     */
    public List<THighpresfire> selectTHighpresfireList(THighpresfire tHighpresfire);

    /**
     * 定时任务查询高压消防炮列表
     *
     * @param tHighpresfire 高压消防炮
     * @return 高压消防炮集合
     */
    public List<THighpresfire> selectList(THighpresfire tHighpresfire);

    /**
     * 新增高压消防炮
     * 
     * @param tHighpresfire 高压消防炮
     * @return 结果
     */
    public int insertTHighpresfire(THighpresfire tHighpresfire);

    /**
     * 修改高压消防炮
     * 
     * @param tHighpresfire 高压消防炮
     * @return 结果
     */
    public int updateTHighpresfire(THighpresfire tHighpresfire);

    /**
     * 批量删除高压消防炮
     * 
     * @param ids 需要删除的高压消防炮ID
     * @return 结果
     */
    public int deleteTHighpresfireByIds(Long[] ids);

    /**
     * 删除高压消防炮信息
     * 
     * @param id 高压消防炮ID
     * @return 结果
     */
    public int deleteTHighpresfireById(Long id);
}
